from distutils.core import setup

setup(
        name         = 'nester_cjs',
        version      = '1.4.0',
        py_modules   = ['nester_cjs'],
        author       = 'cjs',
        author_email = '912090789@qq.com',
        url          = 'http://www.headfirstlabs.com',
        description  = 'A simple printer of nested lists',       
      )
